@@ -14,16 +14,13 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '3.4';    # VERSION
+our $VERSION = '3.5';    # VERSION
 my @OPTIONS_ATTRIBUTES
     = qw/format short repeatable negativable autosplit doc/;
 
-# todo to support multiple role
-# { package $target; sub _option_information { shift->maybe::next::method(@_) } }
-
 sub import {
     my ( undef, @import ) = @_;
-    my $import_options
+    my $options_config
         = { protect_argv => 1, flavour => [], skip_options => [], @import };
 
     my $target = caller;
@@ -31,70 +28,64 @@ sub import {
     my $around = $target->can('around');
     my $has    = $target->can('has');
 
-    my $options_meta = {};
+    my @target_isa;
+    { no strict 'refs'; @target_isa = @{"${target}::ISA"} };
+
+    if (@target_isa) {
+
+        #don't add this to a role
+        #ISA of a role is always empty !
+        ## no critic qw/ProhibitStringyEval/
+        use warnings FATAL => 'redefine';
+        eval '{
+        package ' . $target . ';
+
+            sub _options_data {
+                my ( $class, @meta ) = @_;
+                return $class->maybe::next::method(@meta);
+            }
+
+            sub _options_config {
+                my ( $class, @params ) = @_;
+                return $class->maybe::next::method(@params);
+            }
+
+        1;
+        }';
+        use warnings FATAL => qw/void/;
+
+        croak $@ if $@;
+
+        $around->(
+            _options_config => sub {
+                my ( $orig, $self ) = ( shift, shift );
+                return $self->$orig(@_), %$options_config;
+            }
+        );
+
+        ## use critic
+    }
+
+    my $options_data = {};
     my $modifier_done;
     my $apply_modifiers = sub {
         return if $modifier_done;
         $with->('MooX::Options::Role');
 
-        ## no critic qw/ProhibitStringyEval/
-        unless (
-            eval '
-        package ' . $target . ';
-
-        sub _options_meta {
-            my ( $class, @meta ) = @_;
-            return $class->maybe::next::method(@meta);
-        }
-
-        sub _options_params {
-            my ( $class, @params ) = @_;
-            return $class->maybe::next::method(@params);
-        }
-        '
-            )
-        {
-            croak $@ if $@;
-        }
-        ## use critic
-
         $around->(
-            _options_meta => sub {
+            _options_data => sub {
                 my ( $orig, $self ) = ( shift, shift );
-                return ( $self->$orig(@_), %$options_meta );
+                return ( $self->$orig(@_), %$options_data );
             }
         );
 
-        $around->(
-            _options_params => sub {
-                my ( $orig, $self ) = ( shift, shift );
-                return $self->$orig(@_), %$import_options;
-
-                #for debug purpose
-                #my @p = $self->$orig(@_);
-                #my @q = %$import_options;
-                #use Carp;
-                #use Data::Dumper;
-                #carp "p:",Dumper \@p;
-                #carp "q:",Dumper \@q;
-                #return @p,@q;
-            }
-        );
-
-        #if ( my $info = $Role::Tiny::INFO{$target} ) {
-        #    for my $sref (qw/meta params/) {
-        #        my $meth = $target->can('_options_' . $sref);
-        #        $info->{not_methods}{$meth} = $meth;
-        #    }
-        #}
-
         $modifier_done = 1;
     };
 
     my $option = sub {
         my ( $name, %attributes ) = @_;
         for my $ban (
-            qw/help option new_with_options parse_options options_usage _options_meta _options_params/
+            qw/help option new_with_options parse_options options_usage _options_data _options_config/
             )
         {
             croak
@@ -104,7 +95,7 @@ sub import {
 
         $has->( $name => _filter_attributes(%attributes) );
 
-        $options_meta->{$name}
+        $options_data->{$name}
             = { _validate_and_filter_options(%attributes) };
 
         $apply_modifiers->();
@@ -157,7 +148,7 @@ MooX::Options - add option keywords to your object (Mo/Moo/Moose)
 
 =head1 VERSION
 
-version 3.4
+version 3.5
 
 =head1 MooX::Options
 
@@ -240,6 +231,7 @@ You can also use it over a Role.
     {
         package t;
         use Moo;
+        use MooX::Options; #you have to add this, or the role will not find the necessary methods
         with 'tRole';
         1;
     }
@@ -444,6 +436,20 @@ Ex :
 
 =back
 
+=head1 namespace::clean
+
+To use namespace::clean you need to add 2 methods as an exception. It is use by MooX::Options when you run the new_with_options methods.
+
+    {
+        package t;
+        use Moo;
+        use MooX::Options;
+        use namespace::clean -except => [qw/_options_data _options_config/];
+        option 'v' => (is => 'rw');
+        1;
+    }
+    my $r = t->new_with_options;
+
 =head1 no more Mouse support
 
 If you are using Mouse, I'm sorry to say than the rewrite of this module has make it just incompatible. Mouse is not design to by compatible with anything else than Mouse itself. I could just suggest to use Moo instead, which is a great and compatible replacement.
